from setuptools import setup, find_packages
setup(
    name='Fcolor',
    version='0.3',
    description='Fcolor pèrmet de facilement gérer les couleures rgb,hex et hsl',
    packages=find_packages(),
    install_requires=[

    ],
)